# SAP Build Integration for SAP Discovery
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/configuring-sap-build-integration#overview)
  * [Prerequisites](https://help.sap.com/docs/leanix/ea/configuring-sap-build-integration#prerequisites)
  * [Step 1: Creating an SAP Build Process Automation Instance and Service Key](https://help.sap.com/docs/leanix/ea/configuring-sap-build-integration#step-1:-creating-an-sap-build-process-automation-instance-and-service-key)
  * [Step 2: Creating an SAP Cloud Management Service Instance and Service Key](https://help.sap.com/docs/leanix/ea/configuring-sap-build-integration#step-2:-creating-an-sap-cloud-management-service-instance-and-service-key)
  * [Step 3: Connecting SAP LeanIX to the SAP Build Instance](https://help.sap.com/docs/leanix/ea/configuring-sap-build-integration#step-3:-connecting-sap-leanix-to-the-sap-build-instance)
  * [Linking Discovered Items to Fact Sheets](https://help.sap.com/docs/leanix/ea/configuring-sap-build-integration#linking-discovered-items-to-fact-sheets)
  * [Viewing Synchronization Logs](https://help.sap.com/docs/leanix/ea/configuring-sap-build-integration#viewing-synchronization-logs)


Connect SAP Build to SAP LeanIX to improve the visibility of self-built applications within your enterprise architecture.
